RevmcMetrics

Struct RevmcMetrics 

pub struct RevmcMetrics {
Show 27 fields pub lookup_hits: Gauge, pub lookup_misses: Gauge, pub events_queued: Gauge, pub events_dropped: Gauge, pub resident_entries: Gauge, pub jit_code_bytes: Gauge, pub jit_data_bytes: Gauge, pub command_queue_len: Gauge, pub pending_jobs: Gauge, pub evictions: Gauge, pub compilations_dispatched: Gauge, pub compilations_succeeded: Gauge, pub compilations_failed: Gauge, pub jit_helper_spawns: Gauge, pub jit_helper_spawn_failures: Gauge, pub jit_helper_restarts: Gauge, pub jit_helper_timeouts: Gauge, pub jit_helper_disconnects: Gauge, pub pauses_total: Counter, pub resumes_total: Counter, pub paused: Gauge, pub jit_compilation_duration: Histogram, pub jit_compilation_duration_last: Gauge, pub jit_parse_duration: Histogram, pub jit_translate_duration: Histogram, pub jit_optimize_duration: Histogram, pub jit_codegen_duration: Histogram,
}
Available on crate feature jit only.
Prometheus metrics for revmc JIT runtime stats.

Fields

lookup_hits: Gauge

Total lookups that returned a compiled function.

lookup_misses: Gauge

Total lookups that returned interpret (not ready).

events_queued: Gauge

Lookup-observed events currently queued.

events_dropped: Gauge

Lookup-observed events dropped (channel full).

resident_entries: Gauge

Number of entries in the resident compiled map.

jit_code_bytes: Gauge

Approximate total bytes of compiled machine code in the resident map.

jit_data_bytes: Gauge

Approximate total bytes of JIT-related data (relocations, metadata, etc.).

command_queue_len: Gauge

Number of pending control commands queued for the backend.

pending_jobs: Gauge

Number of compilation jobs dispatched but not completed yet.

evictions: Gauge

Total number of entries evicted (idle + budget).

compilations_dispatched: Gauge

Total number of compilations dispatched (JIT promotions + AOT requests).

compilations_succeeded: Gauge

Total number of successful compilations (JIT + AOT).

compilations_failed: Gauge

Total number of failed compilations (JIT + AOT).

jit_helper_spawns: Gauge

Total number of JIT helper processes spawned.

jit_helper_spawn_failures: Gauge

Total number of JIT helper process spawn failures.

jit_helper_restarts: Gauge

Total number of JIT helper process restarts.

jit_helper_timeouts: Gauge

Total number of JIT helper job timeouts.

jit_helper_disconnects: Gauge

Total number of JIT helper process disconnects.

pauses_total: Counter

Total number of transitions into paused JIT helper execution.

resumes_total: Counter

Total number of transitions out of paused JIT helper execution.

paused: Gauge

Whether JIT helper execution is currently paused.

jit_compilation_duration: Histogram

Histogram of total JIT compilation durations (seconds).

jit_compilation_duration_last: Gauge

Duration of the last JIT compilation (seconds).

jit_parse_duration: Histogram

Histogram of parse phase durations (seconds).

jit_translate_duration: Histogram

Histogram of translate phase durations (seconds).

jit_optimize_duration: Histogram

Histogram of optimize phase durations (seconds).

jit_codegen_duration: Histogram

Histogram of codegen phase durations (seconds).

Implementations

Source

impl RevmcMetrics

pub fn new_with_labels(labels: impl IntoLabels) -> Self

Creates a new instance of the metrics with the provided labels.

Unlike Self::default, this does not cache the result, so it can be used to re-register metrics or register with different labels.

pub fn describe()

Describe all exposed metrics.

Internally, this calls the describe_* macros from the metrics crate according to the metric type.

This is done only once, to avoid multiple describe calls to the same recorder. If this is not preferred, you can call Self::force_describe directly.

See: https://docs.rs/metrics/latest/metrics/index.html#macros

pub fn force_describe()

Unconditionally describes all metrics.

See Self::describe.

Source

impl RevmcMetrics

pub fn record(&self, stats: &RuntimeStatsSnapshot)

Records a RuntimeStatsSnapshot into the metrics.

pub fn record_compilation(&self, event: &CompilationEvent)

Records a CompilationEvent into the histogram metrics.